measuretools.get_likely_multiplier_of_components
================================================

.. autofunction:: abjad.tools.measuretools.get_likely_multiplier_of_components.get_likely_multiplier_of_components
   :noindex:
